#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""FAL command for handling Shares Ctrl event"""

from ionas.request import Entry
from iobase.exception import ExecError, NotFoundError
import libevh.evhcmd as evhcmd
import fal_info
from product_conf.reqinfo import Results, ReqTypes
from libevh.util import is_mounted, is_share_mode_by_vol_name


SHARES_PATH = "eventinfo/shares"
REPLICATION_PATH = SHARES_PATH + "/share/replication"
PATH_PATH = SHARES_PATH + "/share/path"

VOL_SEP = "/"
VOLUME_IDX = 1


class EvhSharesCtrl(evhcmd.EvhCmd):
    """Shares Ctrl Event Handler command implementation class."""

    #
    # Utility method
    #

    def __is_replication_enabled(self, entry):

        try:
            if entry.get().get_node(REPLICATION_PATH).is_enabled():
                return True
            return False
        except NotFoundError:
            return False

    def __send_request(self, type, entry):

        res_entry = self.send_entry(
            Entry(type, entry.get().get_node(SHARES_PATH)),
            fal_info.FAL_REPLICATION_PATH)

        if res_entry.get_result() != Results.OK:
            raise ExecError(fal_info.FAL_REPLICATION_PATH)

    def __is_enable_share(self, entry):

        share_path = entry.get().get_value(PATH_PATH)
        vol_name = share_path.lstrip(VOL_SEP).split(VOL_SEP)[VOLUME_IDX]

        if (is_mounted(vol_name) and is_share_mode_by_vol_name(vol_name)):
            return True
        return False

    #
    # Request handlers
    #

    def __event_handler(self, entry):
        """Handle "event" request."""

        if (self.__is_replication_enabled(entry) and
            self.__is_enable_share(entry)):
            self.__send_request(ReqTypes.SET, entry)
        else:
            self.__send_request(ReqTypes.UNSET, entry)

        entry.set_result(Results.OK)
        return entry

    def __init__(self):
        """Constructor."""

        evhcmd.EvhCmd.__init__(self, evhcmd.EvhCmdOption())

        self.set_handler(ReqTypes.EVENT, self.__event_handler)

#
# Main
#

if __name__ == "__main__":
    EvhSharesCtrl().handle_request()
