# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from django.utils.translation import ugettext as _
from django.http import HttpResponseRedirect, HttpResponse
from django import forms
from django.core.validators import EMPTY_VALUES
import os
import datetime
from project.view import FuncView
import settings

from project.fal.replication import Replication
from project.fal.share import Share

from fields import (ReplicationScheduleEnabledField,
                    ReplicationScheduleWeekdaysField,
                    ReplicationScheduleTimeField)
from fal import FALcReplication, dict__get


class ReplicationSettingsForm(forms.Form):

    weekly_enabled = ReplicationScheduleEnabledField()
    weekly_weekdays = ReplicationScheduleWeekdaysField(required=False)
    weekly_time = ReplicationScheduleTimeField(required=False)

    def clean_weekly_weekdays(self):
        value = self.cleaned_data["weekly_weekdays"]
        if self.cleaned_data.get("weekly_enabled"):
            if value in EMPTY_VALUES:
                raise forms.ValidationError(_(u"This field is required."))
        return value

    def clean_weekly_time(self):
        value = self.cleaned_data["weekly_time"]
        if self.cleaned_data.get("weekly_enabled"):
            if value in EMPTY_VALUES:
                raise forms.ValidationError(_(u"This field is required."))
        return value


class ReplicationSettingsView(FuncView):

    views = ["apply"]

    def view(self, request):
        form = ReplicationSettingsForm(initial=self.__initial())

        template = os.path.join(self.TEMPLATES, "template.html")
        dictionary = {
            "form": form,
        }
        return {
            self.KEY_TEMPLATE: template,
            self.KEY_TEMPLATE_DIC: dictionary,
        }

    def view_apply(self, request):
        form = ReplicationSettingsForm(data=request.POST)

        with self.processing() as p:
            if form.is_valid():
                replication = FALcReplication()
                cleaned_data = form.cleaned_data
                result = replication.save({
                    "schedule": {
                        "weekly": {
                            "enabled": cleaned_data["weekly_enabled"],
                            "weekdays": dict([(day, day in cleaned_data["weekly_weekdays"]) for day in ("sun", "mon", "tue", "wed", "thu", "fri", "sat")]),
                            "time": cleaned_data["weekly_time"],
                        },
                    },
                })
                self.set_message(replication.get_message())
                p.result(result)

        template = os.path.join(self.TEMPLATES, "template.html")
        dictionary = {
            "form": form,
        }
        return {
            self.KEY_TEMPLATE: template,
            self.KEY_TEMPLATE_DIC: dictionary,
        }

    def __initial(self):
        initial = {}
        try:
            data = FALcReplication().load()
            initial = {
                "weekly_enabled": dict__get(data, ["schedule", "weekly", "enabled"], default=False),
                "weekly_weekdays": [day for day, enabled in dict__get(data, ["schedule", "weekly", "weekdays"], default={}).iteritems() if enabled],
                "weekly_time": dict__get(data, ["schedule", "weekly", "time"], default=datetime.time(0, 0)),
            }
        except:
            pass
        return initial
